@@ -1,12 +1,12 @@
 package SPOPS::HashFile;
 
-# $Id: HashFile.pm,v 3.1 2003/01/02 06:00:25 lachoy Exp $
+# $Id: HashFile.pm,v 3.3 2003/12/06 03:13:59 lachoy Exp $
 
 use strict;
 use base  qw( SPOPS );
 use Data::Dumper;
 
-$SPOPS::HashFile::VERSION  = sprintf("%d.%02d", q$Revision: 3.1 $ =~ /(\d+)\.(\d+)/);
+$SPOPS::HashFile::VERSION  = sprintf("%d.%02d", q$Revision: 3.3 $ =~ /(\d+)\.(\d+)/);
 
 # Just grab the tied hash from the SPOPS::TieFileHash
 
@@ -113,8 +113,10 @@ sub remove {
 
 sub clone {
     my ( $self, $p ) = @_;
-    $p->{filename} ||= tied %{ $self }->{filename};
-    my $new = $self->new( { filename => $p->{filename}, perm => $p->{perm} } );
+    unless ( $p->{filename} ) {
+        $p->{filename} = (tied %{ $self })->{filename};
+    }
+    my $new = $self->new({ filename => $p->{filename}, perm => $p->{perm} });
     while ( my ( $k, $v ) = each %{ $self } ) {
         $new->{ $k } = $p->{ $k } || $v;
     }
@@ -128,7 +130,7 @@ package SPOPS::TieFileHash;
 use strict;
 use File::Copy qw( cp );
 
-$SPOPS::TieFileHash::VERSION  = sprintf("%d.%02d", q$Revision: 3.1 $ =~ /(\d+)\.(\d+)/);
+$SPOPS::TieFileHash::VERSION  = sprintf("%d.%02d", q$Revision: 3.3 $ =~ /(\d+)\.(\d+)/);
 
 # These are all very standard routines for a tied hash; more info: see
 # 'perldoc Tie::Hash'
