@@ -1,8 +1,10 @@
 #!/usr/bin/perl
 
-# $Id: stock_doodads.pl,v 3.0 2002/08/28 01:16:32 lachoy Exp $
+# $Id: stock_doodads.pl,v 3.1 2004/01/10 02:49:58 lachoy Exp $
 
 use strict;
+use Log::Log4perl;
+Log::Log4perl::init( 'log4perl.conf' );
 
 require My::Security;
 require My::User;
